import { visit } from "unist-util-visit";
import { isEqual, merge as lodashMerge } from "lodash-es";
import yaml from "yaml";
const jsonStringify = (dataToStringify) => {
    return JSON.stringify(dataToStringify, null, 2);
};
export const remarkMergeData = (mergeDataOptions) => {
    const optionsArray = Array.isArray(mergeDataOptions)
        ? mergeDataOptions
        : [mergeDataOptions];
    return (tree) => {
        visit(tree, "code", function (node) {
            for (const options of optionsArray) {
                const { data, lang, isYaml, merge, meta, parse, stringify } = options;
                if (node.lang !== lang) {
                    continue;
                }
                if (meta) {
                    if (!node.meta) {
                        continue;
                    }
                    const nodeMeta = Object.fromEntries(node.meta.split(" ").map((entry) => {
                        return entry.split("=");
                    }));
                    if (!isEqual(nodeMeta, meta)) {
                        continue;
                    }
                }
                const mergeFunction = merge || lodashMerge;
                const parseFunction = parse || isYaml ? (code) => yaml.parse(code) : JSON.parse;
                const stringifyFunction = stringify || isYaml ? yaml.stringify : jsonStringify;
                const documentData = parseFunction(node.value);
                node.value = stringifyFunction(mergeFunction({}, isYaml ? parseFunction(data) : data, documentData));
            }
        });
    };
};
